@@ -1,17 +1,10 @@
-from . import examples
-
 import pytest
 
 
-@pytest.fixture
-def anchor_args():
-    return ["-v", "--check-links", "--check-anchors"]
-
-
 def test_anchors_local_self(testdir, anchor_args):
     testdir.copy_example('anchors_self.html')
     result = testdir.runpytest(*anchor_args)
-    result.assert_outcomes(passed=1, failed=2)
+    result.assert_outcomes(passed=2, failed=2)
 
 
 def test_anchors_local_other(testdir, anchor_args):
